@@ -81,10 +81,10 @@ wflow_view <- function(files = NULL, latest = FALSE, dry_run = FALSE,
   if (!is.null(files)) {
     if (!(is.character(files) && length(files) > 0))
       stop("files must be NULL or a character vector of filenames")
-    if (any(dir.exists(files)))
+    if (any(fs::dir_exists(files)))
       stop("files cannot include a path to a directory")
     files <- glob(files)
-    if (!all(file.exists(files)))
+    if (!all(fs::file_exists(files)))
       stop("Not all files exist. Check the paths to the files")
     # Change filepaths to relative paths
     files <- relative(files)
@@ -101,7 +101,7 @@ wflow_view <- function(files = NULL, latest = FALSE, dry_run = FALSE,
     stop("dry_run must be a one element logical vector. You entered: ", dry_run)
   if (!(is.character(project) && length(project) == 1))
     stop("project must be a one element character vector. You entered: ", project)
-  if (!dir.exists(project))
+  if (!fs::dir_exists(project))
     stop("project does not exist. You entered: ", project)
 
   project <- absolute(project)
@@ -150,7 +150,7 @@ wflow_view <- function(files = NULL, latest = FALSE, dry_run = FALSE,
 
   # Check for misssing HTML files ----------------------------------------------
 
-  html_missing <- !file.exists(html)
+  html_missing <- !fs::file_exists(html)
   if (any(html_missing)) {
     warning("The following HTML files are missing:\n",
             paste(html[html_missing], collapse = "\n"))
@@ -217,8 +217,7 @@ print.wflow_view <- function(x, ...) {
     cat(wrap(
       "wflow_view will not open any files because no option is set for a
       default browser. See the Details section of ?browseURL for setup
-      instructions.\n"
-      ))
+      instructions."), sep = "\n")
 
     return(invisible(x))
   }
