@@ -136,10 +136,36 @@ test_that("warn_branch_mismatch warns if local and remote branch do *not* match"
                "The remote branch is \"a\", but the current local branch is \"b\".")
 })
 
+# Test get_remote_protocol -----------------------------------------------------
+
+test_that("get_remote_protocol can detect HTTPS remote", {
+  protocol <- get_remote_protocol(remote = "https://github.com/user/repo.git",
+                                  remote_avail = remote_avail)
+  expect_identical(protocol, "https")
+})
+
+test_that("get_remote_protocol can detect HTTPS remote by alias", {
+  protocol <- get_remote_protocol(remote = "upstream",
+                                  remote_avail = remote_avail)
+  expect_identical(protocol, "https")
+})
+
+test_that("get_remote_protocol can detect SSH remote", {
+  protocol <- get_remote_protocol(remote = "git@github.com:user/repo.git",
+                                  remote_avail = remote_avail)
+  expect_identical(protocol, "ssh")
+})
+
+test_that("get_remote_protocol fails for unknown protocol", {
+  expect_error(get_remote_protocol(remote = "xyz:user/repo.git",
+                                   remote_avail = remote_avail),
+               "The URL to the remote repository is using an unknown protocol")
+})
+
 # Test authenticate_git --------------------------------------------------------
 
 test_that("authenticate_git can create HTTPS credentials", {
-  cred <- authenticate_git(remote = "upstream", remote_avail = remote_avail,
+  cred <- authenticate_git(protocol = "https",
                            username = "fakeuser", password = "fakepass")
   expect_true(class(cred) == "cred_user_pass")
   expect_true(git2r_slot(cred, "username") == "fakeuser")
@@ -147,17 +173,29 @@ test_that("authenticate_git can create HTTPS credentials", {
 })
 
 test_that("authenticate_git returns NULL for SSH remotes", {
-  cred <- authenticate_git(remote = "git@github.com:user/repo.git",
-                           remote_avail = remote_avail)
+  cred <- authenticate_git(protocol = "ssh")
   expect_true(is.null(cred))
 })
 
-test_that("authenticate_git fails for unknown protocol", {
-  expect_error(authenticate_git(remote = "xyz:user/repo.git",
-                                remote_avail = remote_avail),
-               "The URL to the remote repository is using an unknown protocol")
+test_that("authenticate_git only accepts https or ssh", {
+  expect_error(authenticate_git(protocol = "xyz"))
 })
 
+test_that("authenticate_git fails if no username provided for https", {
+
+  if (interactive()) skip("Interactive session")
+
+  expect_error(authenticate_git(protocol = "https", password = "fakepass"),
+               "No username was specified")
+})
+
+test_that("authenticate_git fails if no password provided for https", {
+
+  if (interactive()) skip("Interactive session")
+
+  expect_error(authenticate_git(protocol = "https", username = "fakeuser"),
+               "No password was specified")
+})
 
 # Test wflow_git_push and wflow_git_pull ---------------------------------------
 
@@ -170,8 +208,10 @@ test_that("wflow_git_push can run in dry-run mode", {
   expect_identical(result$branch, "master")
   expect_identical(result$force, FALSE)
   expect_identical(result$dry_run, TRUE)
+  expect_identical(result$protocol, "https")
   # Test print method
   expect_true("  $ git push origin master" %in% utils::capture.output(result))
+  expect_true("Using the HTTPS protocol" %in% utils::capture.output(result))
 })
 
 test_that("wflow_git_pull can run in dry-run mode", {
@@ -179,8 +219,32 @@ test_that("wflow_git_pull can run in dry-run mode", {
   expect_identical(result$remote, "origin")
   expect_identical(result$branch, "master")
   expect_identical(result$dry_run, TRUE)
+  expect_identical(result$protocol, "https")
   # Test print method
   expect_true("  $ git pull origin master" %in% utils::capture.output(result))
+  expect_true("Using the HTTPS protocol" %in% utils::capture.output(result))
+})
+
+test_that("wflow_git_push/pull fail early if try to use SSH protocol when not supported", {
+
+  wflow_git_remote(remote = "testssh", user = "user", repo = "repo",
+                   protocol = "ssh", project = site_dir)
+
+  if (git2r::libgit2_features()$ssh) {
+    expect_silent(wflow_git_push(remote = "testssh", dry_run = TRUE,
+                                 project = site_dir))
+    expect_silent(wflow_git_pull(remote = "testssh", dry_run = TRUE,
+                                 project = site_dir))
+  } else {
+    expect_error(wflow_git_push(remote = "testssh", dry_run = TRUE,
+                                project = site_dir),
+                 "You cannot use the SSH protocol")
+    expect_error(wflow_git_pull(remote = "testssh", dry_run = TRUE,
+                                project = site_dir),
+                 "You cannot use the SSH protocol")
+  }
+
+  wflow_git_remote(remote = "testssh", action = "remove", project = site_dir)
 })
 
 # Test print.wflow_git_pull ----------------------------------------------------
