@@ -1,6 +1,6 @@
 context("wflow_remove")
 
-# Setup -----------------------------------------------------------------------
+# Setup ------------------------------------------------------------------------
 
 library("git2r")
 
@@ -29,11 +29,10 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
   # Create an Rmd and a data file to be removed later. Add a chunk with a plot and
   # that is cached. Publish this analysis.
   rmd_published <- file.path(p$analysis, "published.Rmd")
-  file.copy(from = file.path(cwd, "files", "example.Rmd"),
-            to = rmd_published)
+  fs::file_copy(file.path(cwd, "files", "example.Rmd"), rmd_published)
   cat(chunk_w_plot, file = rmd_published, sep = "\n", append = TRUE)
   data_published <- file.path("data", "published.txt")
-  file.create(data_published)
+  fs::file_create(data_published)
   suppressMessages(x <- wflow_publish(c(rmd_published, data_published), view = FALSE))
   cache_published <- file.path(p$analysis,
                                paste0(tools::file_path_sans_ext(
@@ -44,9 +43,9 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
   # Create an Rmd and a data file to be removed later. Add a chunk with a plot and
   # that is cached. Build but do not publish this analysis.
   rmd_unpublished <- file.path(p$analysis, "unpublished.Rmd")
-  file.copy(from = rmd_published, to = rmd_unpublished)
+  fs::file_copy(rmd_published, rmd_unpublished)
   data_unpublished <- file.path("data", "unpublished.txt")
-  file.create(data_unpublished)
+  fs::file_create(data_unpublished)
   suppressMessages(x <- wflow_build(rmd_unpublished, view = FALSE))
   cache_unpublished <- file.path(p$analysis,
                                  paste0(tools::file_path_sans_ext(
@@ -69,12 +68,15 @@ test_that("wflow_remove removes an unpublished Rmd file and its associated files
   expect_identical(actual$dry_run, TRUE)
   expect_identical(actual$commit, NA)
   expect_identical(actual$files_git, character())
-  expect_true(all(file.exists(rmd_unpublished, data_unpublished),
-                  dir.exists(c(cache_unpublished, fig_docs_unpublished))))
+  expect_true(all(fs::file_exists(c(rmd_unpublished, data_unpublished)),
+                  fs::dir_exists(c(cache_unpublished, fig_docs_unpublished))))
   # Now remove the files
   actual <- wflow_remove(c(rmd_unpublished, data_unpublished))
-  expect_false(any(file.exists(rmd_unpublished, data_unpublished),
-                  dir.exists(c(cache_unpublished, fig_docs_unpublished))))
+  expect_false(any(fs::file_exists(c(rmd_unpublished, data_unpublished)),
+                  fs::dir_exists(c(cache_unpublished, fig_docs_unpublished))))
+  # Test print method
+  expect_output(print(actual), rmd_unpublished)
+  expect_output(print(actual), data_unpublished)
 })
 
 test_that("wflow_remove removes a published Rmd file and its associated files", {
@@ -89,14 +91,18 @@ test_that("wflow_remove removes a published Rmd file and its associated files",
   expect_identical(actual$dry_run, TRUE)
   expect_identical(actual$commit, NA)
   expect_true(all(c(rmd_published, data_published) %in% actual$files_git))
-  expect_true(all(file.exists(rmd_published, data_published),
-                  dir.exists(c(cache_published, fig_docs_published))))
+  expect_true(all(fs::file_exists(c(rmd_published, data_published)),
+                  fs::dir_exists(c(cache_published, fig_docs_published))))
   files_committed <- workflowr:::get_committed_files(r)
   expect_true(all(c(rmd_published, data_published) %in% relative(files_committed)))
   # Now remove the files
   actual <- wflow_remove(c(rmd_published, data_published))
-  expect_false(any(file.exists(rmd_published, data_published),
-                   dir.exists(c(cache_published, fig_docs_published))))
+  expect_false(any(fs::file_exists(c(rmd_published, data_published)),
+                   fs::dir_exists(c(cache_published, fig_docs_published))))
+  # Test print method
+  expect_output(print(actual), rmd_published)
+  expect_output(print(actual), data_published)
+  # Confirm a commit was made
   commit_latest <- commits(r)[[1]]
   expect_identical(git2r_slot(actual$commit, "sha"),
                    git2r_slot(commit_latest, "sha"))
@@ -116,10 +122,10 @@ test_that("wflow_remove can remove files with no Git repo present", {
   # The test will remove README, so restore it afterwards
   f <- "README.md"
   on.exit(checkout(r, path = f), add = TRUE)
-  expect_true(file.exists(f))
+  expect_true(fs::file_exists(f))
   # Remove README.md
   expect_silent(actual <- wflow_remove(f))
-  expect_false(file.exists(f))
+  expect_false(fs::file_exists(f))
   expect_identical(actual$files, f)
   expect_identical(actual$commit, NA)
   expect_identical(actual$files_git, NA)
@@ -127,31 +133,100 @@ test_that("wflow_remove can remove files with no Git repo present", {
 
 test_that("wflow_remove can remove a directory", {
   d <- "toplevel"
-  dir.create(d)
+  fs::dir_create(d)
   on.exit(unlink(d, recursive = TRUE, force = TRUE))
   f <- file.path(d, "file")
-  file.create(f)
+  fs::file_create(f)
   add(r, f)
   commit(r, "new file")
   actual <- wflow_remove(d)
   expect_identical(actual$files_git, f)
-  expect_false(dir.exists(d))
-  expect_false(file.exists(f))
+  expect_false(fs::dir_exists(d))
+  expect_false(fs::file_exists(f))
+})
+
+# Test needed to handle Windows behavior of fs::file_exists
+test_that("wflow_remove can remove a directory with a trailing slash", {
+  d <- "toplevel/"
+  fs::dir_create(d)
+  on.exit(unlink(d, recursive = TRUE, force = TRUE))
+  f <- file.path(d, "file")
+  fs::file_create(f)
+  add(r, f)
+  commit(r, "new file")
+  actual <- wflow_remove(d)
+  expect_identical(actual$files_git, workflowr:::relative(f))
+  expect_false(fs::dir_exists(d))
+  expect_false(fs::file_exists(f))
 })
 
 test_that("wflow_remove can remove a file with a relative path from a subdir", {
   rmd <- file.path(p$analysis, "new.Rmd")
-  file.create(rmd)
+  fs::file_create(rmd)
   add(r, rmd)
   commit(r, "Add an rmd file to remove")
 
   expect_silent(with_dir("code/",
                          o <- wflow_remove(file.path("../analysis", basename(rmd)))))
-  expect_false(file.exists(rmd))
+  expect_false(fs::file_exists(rmd))
   s <- status(r)
   expect_equal(length(s$untracked) + length(s$unstaged) + length(s$staged), 0)
 })
 
+test_that("wflow_remove can remove figure file from analysis/", {
+  rmd <- file.path(p$analysis, "new.Rmd")
+  fs::file_create(rmd)
+  dir_fig <- file.path(p$analysis, workflowr:::create_figure_path(rmd))
+  fs::dir_create(dir_fig)
+  fig <- file.path(dir_fig, "test.png")
+  fs::file_create(fig)
+  expect_silent(actual <- wflow_remove(rmd))
+  expect_identical(actual$files, c(rmd, fig))
+  expect_false(fs::file_exists(rmd))
+  expect_false(fs::file_exists(fig))
+  expect_false(fs::dir_exists(dir_fig))
+
+  # Same thing, but from analysis/ subdirectory
+  rmd <- file.path(p$analysis, "new.Rmd")
+  fs::file_create(rmd)
+  dir_fig <- file.path(p$analysis, workflowr:::create_figure_path(rmd))
+  fs::dir_create(dir_fig)
+  fig <- file.path(dir_fig, "test.png")
+  fs::file_create(fig)
+  expect_silent(with_dir(p$analysis,
+                         actual <- wflow_remove(file.path("../analysis", basename(rmd)))))
+  expect_false(fs::file_exists(rmd))
+  expect_false(fs::file_exists(fig))
+  expect_false(fs::dir_exists(dir_fig))
+})
+
+test_that("wflow_remove can remove figure file from docs/", {
+  rmd <- file.path(p$analysis, "new.Rmd")
+  fs::file_create(rmd)
+  dir_fig <- file.path(p$docs, workflowr:::create_figure_path(rmd))
+  fs::dir_create(dir_fig)
+  fig <- file.path(dir_fig, "test.png")
+  fs::file_create(fig)
+  expect_silent(actual <- wflow_remove(rmd))
+  expect_identical(actual$files, c(rmd, fig))
+  expect_false(fs::file_exists(rmd))
+  expect_false(fs::file_exists(fig))
+  expect_false(fs::dir_exists(dir_fig))
+
+  # Same thing, but from docs/ subdirectory
+  rmd <- file.path(p$analysis, "new.Rmd")
+  fs::file_create(rmd)
+  dir_fig <- file.path(p$docs, workflowr:::create_figure_path(rmd))
+  fs::dir_create(dir_fig)
+  fig <- file.path(dir_fig, "test.png")
+  fs::file_create(fig)
+  expect_silent(with_dir(p$docs,
+                         actual <- wflow_remove(file.path("../analysis", basename(rmd)))))
+  expect_false(fs::file_exists(rmd))
+  expect_false(fs::file_exists(fig))
+  expect_false(fs::dir_exists(dir_fig))
+})
+
 # Test error handling ----------------------------------------------------------
 
 test_that("wflow_remove requires valid argument: files", {
